@@ -213,7 +213,7 @@ class reachability(object):
         S_i=S_0
         logging.info("number of generators S_0: " + str(np.size(S_0['g'], 1)))
         # 4. step
-        for i in range(0, self.params['N'] - 1):
+        for i in range(0, self.params['N']):
             logging.info("cycle i: "+str(i))
             # 5. step
             X_i = self.multiplication_on_zonotype(self.Phi, X_i)
@@ -270,7 +270,7 @@ class reachability(object):
         S_i=S_0
         logging.info("number of generators S_0: " + str(np.size(S_0['g'], 1)))
         # 4. step
-        for i in range(0, self.params['N'] - 1):
+        for i in range(0, self.params['N']):
             logging.info("cycle i: "+str(i))
             # 5. step
             X_i = self.multiplication_on_zonotype(self.Phi, X_i)
